@@ -6,13 +6,14 @@ This encompasses all the different humanoids, as well as enemy creatures, and ev
 ```
 use rpgstat::stats::Basic as Stats;
 use rpgstat::class::Basic as Class;
-// this is the thing we need!
+use rpgstat::creature::Animal;
 use rpgstat::stats::Builder;
+
 let bear:Animal = Animal::Bear;
 // this number only matters if you want
-let id:f64 = 0;
+let id:f64 = 0.0;
 // this effects the stats returned
-let level:f64 = 1;
+let level:f64 = 1.0;
 // use the basic `Builder`
 let bear_stats:Stats<f64> = bear.build_basic(id, level);
 ```
@@ -23,10 +24,11 @@ use std::fmt;
 use strum::IntoEnumIterator;
 use strum_macros::EnumIter;
 use std::ops::{Add, AddAssign,  Div, DivAssign, Mul, MulAssign, Neg, Rem, RemAssign, Sub, SubAssign};
+use serde::{Deserialize, Serialize};
 
 use crate::stats::{ Builder, Basic, Normal, Advanced };
 
-#[derive(Clone, PartialEq, Copy, Debug, EnumIter)]//, Serialize, Deserialize)]
+#[derive(Clone, PartialEq, Copy, Debug, EnumIter, Serialize, Deserialize)]
 /// The Person class of creature types
 pub enum Person {
     /// These little guys rock!
